@@ -2,11 +2,12 @@
 
 __author__ = r'wsb310@gmail.com'
 
-from hagworm.extend.base import Utils
-from hagworm.extend.cache import StackCache
+from ..base import Utils
+from ..cache import StackCache
+from ..error import catch_error
 
-from hagworm.extend.asyncio.net import HTTPClientPool
-from hagworm.extend.asyncio.future import ThreadPool
+from .net import HTTPClientPool
+from .future import ThreadPool
 
 
 class FileLoader:
@@ -29,7 +30,7 @@ class FileLoader:
 
         result = None
 
-        try:
+        with catch_error():
 
             if self._cache.has(file):
 
@@ -41,17 +42,13 @@ class FileLoader:
 
                 self._cache.set(file, result)
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def fetch(self, url, params=None, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with catch_error():
 
             if self._cache.has(url):
 
@@ -63,8 +60,4 @@ class FileLoader:
 
                 self._cache.set(url, result)
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
