@@ -12,23 +12,38 @@ class ObjectPool:
     """对象池实现
     """
 
-    def __init__(self, maxsize):
+    def __init__(self, maxsize, debug=False):
+
+        self._maxsize = maxsize
+        self._debug = debug
 
         self._queue = Queue(maxsize=maxsize)
 
         for _ in range(maxsize):
             self._queue.put_nowait(self._create_obj())
 
-        Utils.log.info(f'ObjectPool {type(self)} initialized: {self._queue.qsize()}')
+        if self._debug:
+            Utils.log.debug(f'ObjectPool {type(self)} initialized: {self._queue.qsize()}')
 
     def _create_obj(self):
 
         raise NotImplementedError()
 
+    @property
+    def maxsize(self):
+
+        return self._maxsize
+
+    @property
+    def size(self):
+
+        return self._queue.qsize()
+
     @asynccontextmanager
     async def get(self):
 
-        Utils.log.debug(f'ObjectPool {type(self)} size: {self._queue.qsize()}')
+        if self._debug:
+            Utils.log.debug(f'ObjectPool {type(self)} size: {self._queue.qsize()}')
 
         obj = await self._queue.get()
 
@@ -42,7 +57,8 @@ class ObjectPool:
     @contextmanager
     def get_nowait(self):
 
-        Utils.log.debug(f'ObjectPool {type(self)} size: {self._queue.qsize()}')
+        if self._debug:
+            Utils.log.debug(f'ObjectPool {type(self)} size: {self._queue.qsize()}')
 
         obj = self._queue.get_nowait()
 
