@@ -861,8 +861,7 @@ class Utils:
     def params_join(cls, params, filters=[]):
 
         if filters:
-            params = {key: val for key,
-                      val in params.items() if key not in filters}
+            params = {key: val for key, val in params.items() if key not in filters}
 
         return r'&'.join(f'{key}={val}' for key, val in sorted(params.items(), key=lambda x: x[0]))
 
@@ -873,6 +872,7 @@ class Utils:
 
         if args:
             result.extend(str(val) for val in args)
+            result.sort()
 
         if kwargs:
             result.append(cls.params_join(kwargs))
