@@ -7,6 +7,7 @@ import dataclasses
 from configparser import RawConfigParser
 
 from .base import Utils
+from .event import EventDispatcher
 
 
 class HostType(str):
@@ -62,17 +63,50 @@ class Field:
         self.section = section
 
 
-class _ConfigureMetaclass(type):
+class ConfigureMetaclass(type):
     """配置类元类，增加dataclass修饰
     """
 
     def __new__(mcs, name, bases, attrs):
-        return dataclasses.dataclass(init=False, frozen=True)(
+        return dataclasses.dataclass(init=False)(
             type.__new__(mcs, name, bases, attrs)
         )
 
 
-class Configure(metaclass=_ConfigureMetaclass):
+class ConfigureBase(metaclass=ConfigureMetaclass):
+    """配置类
+    """
+
+    __slots__ = [r'_event_dispatcher', r'_key_section']
+
+    def __init__(self):
+
+        super().__init__()
+
+        temp = self.__dataclass_fields__
+
+        self._event_dispatcher = EventDispatcher()
+
+        self._key_section = {
+            f'{_field.default.section}/{_key}': (_key, _field.default.section, _field.type,)
+            for _key, _field in self.__dataclass_fields__.items()
+        }
+
+    def __setattr__(self, key, value):
+
+        super().__setattr__(key, value)
+
+        if key in self.__dataclass_fields__:
+            self._event_dispatcher.dispatch(key, key, value)
+
+    def add_listener(self, key, _callable):
+        return self._event_dispatcher.add_listener(key, _callable)
+
+    def remove_listener(self, key, _callable):
+        return self._event_dispatcher.remove_listener(key, _callable)
+
+
+class Configure(ConfigureBase):
     """配置类
     """
 
@@ -82,28 +116,22 @@ class Configure(metaclass=_ConfigureMetaclass):
 
         super().__init__()
 
-        self._set_attr(r'_parser', RawConfigParser())
+        self._parser = RawConfigParser()
 
-    def _set_attr(self, name, value):
-        super().__setattr__(name, value)
+    def _load_options(self):
 
-    def _init_options(self):
-
-        for _name, _field in self.__dataclass_fields__.items():
-
-            _type = _field.type
-            _section = _field.default.section
+        for _key, _section, _type in self._key_section.values():
 
             if _type is str:
-                self._set_attr(_name, self._parser.get(_section, _name))
+                self.__setattr__(_key, self._parser.get(_section, _key))
             elif _type is int:
-                self._set_attr(_name, self._parser.getint(_section, _name))
+                self.__setattr__(_key, self._parser.getint(_section, _key))
             elif _type is float:
-                self._set_attr(_name, self._parser.getfloat(_section, _name))
+                self.__setattr__(_key, self._parser.getfloat(_section, _key))
             elif _type is bool:
-                self._set_attr(_name, self._parser.getboolean(_section, _name))
+                self.__setattr__(_key, self._parser.getboolean(_section, _key))
             else:
-                self._set_attr(_name, _type.decode(self._parser.get(_section, _name)))
+                self.__setattr__(_key, _type.decode(self._parser.get(_section, _key)))
 
     def get_option(self, section, option):
 
@@ -128,25 +156,25 @@ class Configure(metaclass=_ConfigureMetaclass):
         for option, value in options.items():
             self._parser.set(section, option, value)
 
-        self._init_options()
+        self._load_options()
 
     def read(self, files):
 
         self._parser.clear()
         self._parser.read(files, r'utf-8')
 
-        self._init_options()
+        self._load_options()
 
     def read_str(self, val):
 
         self._parser.clear()
         self._parser.read_string(val)
 
-        self._init_options()
+        self._load_options()
 
     def read_dict(self, val):
 
         self._parser.clear()
         self._parser.read_dict(val)
 
-        self._init_options()
+        self._load_options()
