@@ -102,3 +102,8 @@ class MySQLClientDestroyed(BaseError):
 # NTP校准异常
 class NTPCalibrateError(BaseError):
     pass
+
+
+# Router异常
+class RouterError(BaseError):
+    pass
