@@ -70,92 +70,174 @@ class InterceptHandler(logging.Handler):
         )
 
 
-class ElasticsearchSink:
-    """Elasticsearch日志投递
-    """
+class ElasticsearchDataStreamUtil:
 
-    def __init__(self, hosts, index, *, buffer_maxsize=0xffff, **kwargs):
+    def __init__(
+            self, elasticsearch: Elasticsearch, alias_name: str, *,
+            rollover_max_age: str = r'1d', rollover_max_primary_shard_size: str = r'50gb',
+            delete_min_age: str = r'30d', refresh_interval: str = r'5s', timestamp_order: str = r'desc'
+    ):
 
-        self._elasticsearch = Elasticsearch(hosts, **kwargs)
-        self._index = index
+        self._elasticsearch = elasticsearch
 
-        self._buffer = queue.Queue(buffer_maxsize)
-        self._closed = False
+        self._alias_name = alias_name
+        self._policy_name = f'{alias_name}-ilm-policy'
 
-        self._init_es_index()
+        self._rollover_max_age = rollover_max_age
+        self._rollover_max_primary_shard_size = rollover_max_primary_shard_size
 
-        self._task = Thread(target=self._do_task)
-        self._task.start()
+        self._delete_min_age = delete_min_age
+        self._refresh_interval = refresh_interval
+        self._timestamp_order = timestamp_order
 
-    def _init_es_index(self):
+    def initialize(self):
 
         try:
 
             indices = self._elasticsearch.indices
 
-            if not indices.exists(index=self._index):
-
-                indices.create(
-                    index=self._index,
-                    mappings={
-                        r'dynamic': r'strict',
-                        r'properties': {
-                            r'extra': {
-                                r'type': r'flattened',
-                            },
-                            r'process': {
-                                r'properties': {
-                                    r'id': {
-                                        r'type': r'keyword',
-                                    },
-                                    r'name': {
-                                        r'type': r'keyword',
-                                        r'ignore_above': 64,
-                                    },
-                                },
-                            },
-                            r'thread': {
-                                r'properties': {
-                                    r'id': {
-                                        r'type': r'keyword',
-                                    },
-                                    r'name': {
-                                        r'type': r'keyword',
-                                        r'ignore_above': 64,
-                                    },
-                                },
-                            },
-                            r'level': {
-                                r'properties': {
-                                    r'no': {
-                                        r'type': r'integer',
-                                    },
-                                    r'name': {
-                                        r'type': r'keyword',
-                                        r'ignore_above': 64,
-                                    },
-                                },
-                            },
-                            r'module': {
-                                r'type': r'text',
-                            },
-                            r'message': {
-                                r'type': r'text',
-                                r'analyzer': r'ik_max_word',
-                                r'search_analyzer': r'ik_smart',
-                            },
-                            r'datetime': {
-                                r'type': r'date',
-                                r'format': r'epoch_millis',
-                            },
-                        }
-                    }
-                )
+            if not indices.exists_alias(name=self._alias_name):
+                self._create_lifecycle()
+                self._create_index_template()
 
         except Exception as err:
 
             sys.stderr.write(str(err))
 
+    def _create_lifecycle(self):
+
+        policy = {
+            r'phases': {
+                r'hot': {
+                    r'actions': {
+                        r'rollover': {
+                            r'max_age': self._rollover_max_age,
+                            r'max_primary_shard_size': self._rollover_max_primary_shard_size,
+                        },
+                        r'set_priority': {
+                            r'priority': 100,
+                        }
+                    },
+                    r'min_age': r'0ms',
+                },
+                r'delete': {
+                    r'actions': {
+                        r'delete': {}
+                    },
+                    r'min_age': self._delete_min_age,
+                },
+            },
+        }
+
+        self._elasticsearch.ilm.put_lifecycle(name=self._policy_name, policy=policy)
+
+    def _create_index_template(self):
+
+        mappings = {
+            r'dynamic': r'strict',
+            r'properties': {
+                r'extra': {
+                    r'type': r'flattened',
+                },
+                r'process': {
+                    r'properties': {
+                        r'id': {
+                            r'type': r'keyword',
+                        },
+                        r'name': {
+                            r'type': r'keyword',
+                            r'ignore_above': 64,
+                        },
+                    },
+                },
+                r'thread': {
+                    r'properties': {
+                        r'id': {
+                            r'type': r'keyword',
+                        },
+                        r'name': {
+                            r'type': r'keyword',
+                            r'ignore_above': 64,
+                        },
+                    },
+                },
+                r'level': {
+                    r'properties': {
+                        r'no': {
+                            r'type': r'integer',
+                        },
+                        r'name': {
+                            r'type': r'keyword',
+                            r'ignore_above': 64,
+                        },
+                    },
+                },
+                r'module': {
+                    r'type': r'text',
+                },
+                r'message': {
+                    r'type': r'text',
+                    r'analyzer': r'ik_max_word',
+                    r'search_analyzer': r'ik_smart',
+                },
+                r'@timestamp': {
+                    r'type': r'date',
+                    r'format': r'epoch_millis',
+                },
+            }
+        }
+
+        template = {
+            r'settings': {
+                r'index': {
+                    r'lifecycle': {
+                        r'name': self._policy_name,
+                    },
+                    r'refresh_interval': self._refresh_interval,
+                    r'sort': {
+                        r'field': r'@timestamp',
+                        r'order': self._timestamp_order,
+                    }
+                },
+            },
+            r'mappings': mappings,
+        }
+
+        self._elasticsearch.indices.put_index_template(
+            name=self._alias_name,
+            template=template,
+            index_patterns=[f'{self._alias_name}*'],
+            data_stream={},
+        )
+
+
+class ElasticsearchSink:
+    """Elasticsearch日志投递
+    """
+
+    def __init__(
+            self, hosts, index, *,
+            buffer_maxsize=0xffff,
+            rollover_max_age: str = r'1d', rollover_max_primary_shard_size: str = r'50gb',
+            delete_min_age: str = r'30d',
+            **kwargs):
+
+        self._elasticsearch = Elasticsearch(hosts, **kwargs)
+
+        self._index = index
+
+        self._buffer = queue.Queue(buffer_maxsize)
+        self._closed = False
+
+        self._task = Thread(target=self._do_task)
+        self._task.start()
+
+        ElasticsearchDataStreamUtil(
+            self._elasticsearch, index,
+            rollover_max_age=rollover_max_age, rollover_max_primary_shard_size=rollover_max_primary_shard_size,
+            delete_min_age=delete_min_age
+        ).initialize()
+
     def write(self, message):
 
         log_extra = message.record[r'extra']
@@ -209,7 +291,7 @@ class ElasticsearchSink:
                                 },
                                 r'module': f"{_row[r'name']}:{_row[r'function']}:{_row[r'line']}",
                                 r'message': _row[r'message'],
-                                r'datetime': int(_row[r'time'].timestamp() * 1000),
+                                r'@timestamp': int(_row[r'time'].timestamp() * 1000),
                             }
                             for _row in records if current_ident != _row[r'thread'].id
                         ]
