@@ -7,10 +7,10 @@ from mq_http_sdk.mq_consumer import MQConsumer as _MQConsumer
 from mq_http_sdk.mq_producer import MQProducer as _MQProducer, MQTransProducer as _MQTransProducer, TopicMessage
 from mq_http_sdk.mq_exception import MQServerException, MQClientNetworkException
 
-from hagworm.extend.interface import TaskInterface
-from hagworm.extend.asyncio.base import Utils, AsyncCirculator
-from hagworm.extend.asyncio.task import IntervalTask
-from hagworm.extend.asyncio.future import ThreadPool
+from ...extend.interface import TaskInterface
+from ...extend.asyncio.base import Utils, AsyncCirculator
+from ...extend.asyncio.task import IntervalTask
+from ...extend.asyncio.future import ThreadPool
 
 
 CLIENT_WAIT_TIMEOUT = 10
